summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/dat/clua/dungeon.lua
diff options
context:
space:
mode:
authorRobert Vollmert <rvollmert@gmx.net>2009-10-21 08:53:14 +0200
committerRobert Vollmert <rvollmert@gmx.net>2009-10-21 08:53:14 +0200
commit6b4885b07d0a5228d7dc20cbbb210a1a168bc8da (patch)
treefb2d389b1ada652eab6fc9076dfa32ba503416ce /crawl-ref/source/dat/clua/dungeon.lua
parent6dc31aef7899c75449f7203809f676057b65f5a3 (diff)
downloadcrawl-ref-6b4885b07d0a5228d7dc20cbbb210a1a168bc8da.tar.gz
crawl-ref-6b4885b07d0a5228d7dc20cbbb210a1a168bc8da.zip
Complete rename to mapgrd.
Previously, I had renamed only the C++-side of things. Also update documentation.
Diffstat (limited to 'crawl-ref/source/dat/clua/dungeon.lua')
-rw-r--r--crawl-ref/source/dat/clua/dungeon.lua4
1 files changed, 2 insertions, 2 deletions
diff --git a/crawl-ref/source/dat/clua/dungeon.lua b/crawl-ref/source/dat/clua/dungeon.lua
index b1cc8de795..f6892870d1 100644
--- a/crawl-ref/source/dat/clua/dungeon.lua
+++ b/crawl-ref/source/dat/clua/dungeon.lua
@@ -76,8 +76,8 @@ function dgn_map_meta_wrap(map, tab)
end
end
- -- Convenience global variable, e.g. grd[x][y] = 'x'
- meta['grd'] = dgn.grd_table(map)
+ -- Convenience global variable, e.g. mapgrd[x][y] = 'x'
+ meta['mapgrd'] = dgn.mapgrd_table(map)
meta['_G'] = meta
meta.wrapped_instance = map